# -*- coding: utf-8 -*-

"""

    use adb to capture the phone screen
    then use hanwang text recognize the text
    then use baidu to search answer

"""
from PIL import Image, ImageGrab
from datetime import datetime
from shutil import copyfile
import os
import time
import win32gui
import win32com.client
import win32con


def analyze_current_screen_text(hld,crop_area, directory=".", compress_level=1):
    """
    capture the android screen now

    :return:
    """
    print("capture time: ", datetime.now().strftime("%H:%M:%S"))
    if hld>0:
        screenshot_filename = "screenshot%s.png"%(str(hld))
        save_text_area = os.path.join(directory, screenshot_filename)
        capture_screen(hld,screenshot_filename, directory,crop_area)
    else:
        screenshot_filename = "screenshot.png"
        save_text_area = os.path.join(directory, "text_area.png")
        capture_screen(hld,screenshot_filename, directory)
        parse_answer_area(os.path.join(directory, screenshot_filename), save_text_area, compress_level, crop_area)
    return get_area_data(save_text_area)

def analyze_stored_screen_text(screenshot_filename="screenshot.png", directory=".", compress_level=1):
    """
    reload screen from stored picture to store
    :param directory:
    :param compress_level:
    :return:
    """
    save_text_area = os.path.join(directory, "text_area.png")
    parse_answer_area(os.path.join(directory, screenshot_filename), save_text_area, compress_level)
    return get_area_data(save_text_area)


def capture_screen(hld,filename="screenshot.png", directory=".",crop_area=(0,0,0,0)):
    """
    use adb tools

    :param filename:
    :param directory:
    :return:
    """
    if hld>0:
        win32gui.ShowWindow(hld, win32con.SW_RESTORE)
        shell = win32com.client.Dispatch("WScript.Shell")
        shell.SendKeys('%')
        win32gui.SetForegroundWindow(hld)
        time.sleep(1)
        left, top, right, bottom = win32gui.GetWindowRect(hld)
        width = right -left
        height = bottom - top
        rangle = (left+ crop_area[0]* width,top+ crop_area[1]*height,right+ crop_area[2]* width,bottom+crop_area[3]*height)
        im = ImageGrab.grab(rangle)
        im.save(os.path.join(directory, filename))
    else:
        os.system("adb shell screencap -p /sdcard/{0}".format(filename))
        os.system("adb pull /sdcard/{0} {1}".format(filename, os.path.join(directory, filename)))


def save_screen(filename="screenshot.png", directory="."):
    """
    Save screen for further test
    :param filename:
    :param directory:
    :return:
    """
    copyfile(os.path.join(directory, filename),
             os.path.join(directory, datetime.now().strftime("%m%d_%H%M%S").join(os.path.splitext(filename))))


def parse_answer_area(source_file, text_area_file, compress_level, crop_area):
    """
    crop the answer area

    :return:
    """

    image = Image.open(source_file)
    if compress_level == 1:
        image = image.convert("L")
    elif compress_level == 2:
        image = image.convert("1")

    width, height = image.size[0], image.size[1]
    print("screen width: {0}, screen height: {1}".format(width, height))

    region = image.crop((width * crop_area[0], height * crop_area[1], width * crop_area[2], height * crop_area[3]))

    region.save(text_area_file)


def get_area_data(text_area_file):
    """

    :param text_area_file:
    :return:
    """
    with open(text_area_file, "rb") as fp:
        image_data = fp.read()
        return image_data
    return ""
