# -*- coding: utf-8 -*-

"""

    baidu ocr

"""

from aip import AipOcr
import json
import requests

def get_text_from_baiduocr(image_data, app_id, app_key, app_secret, api_version=0, timeout=3):
    """
    Get image text use baidu ocr

    :param image_data:
    :param app_id:
    :param app_key:
    :param app_secret:
    :param api_version:
    :param timeout:
    :return:
    """
    client = AipOcr(appId=app_id, apiKey=app_key, secretKey=app_secret)
    client.setConnectionTimeoutInMillis(timeout * 1000)

    options = {}
    options["language_type"] = "CHN_ENG"

    if api_version == 1:
        result = client.basicAccurate(image_data, options)
    else:
        result = client.basicGeneral(image_data, options)

    if "error_code" in result:
        print("baidu api error: ", result["error_msg"])
        return ""
    return [words["words"] for words in result["words_result"]]

def get_text_from_spaceocr(image_data, api_key='6c851da45688957', overlay=False, language='chs'):
    """
    CR.space API request with local file.
    :param image_data: image's base64 encoding.
    :param overlay: Is OCR.space overlay required in your response.
                    Defaults to False.
    :param api_key: OCR.space API key.
                    Defaults to 'helloworld'.
    :param language: Language code to be used in OCR.
                    List of available language codes can be found on https://ocr.space/OCRAPI
                    Defaults to 'en'.
    :return: Result in JSON format.
    """
    payload = {
        'isOverlayRequired': overlay,
        'apikey': api_key,
        'language': language,
    }
    r = requests.post('https://api.ocr.space/parse/image',
                      files={'image.png': image_data},
                      data=payload,
                      )
    result = json.loads(r.content)
    if (result['OCRExitCode'] == 1):
        return result['ParsedResults'][0]['ParsedText']
    print(result['ErrorMessage'])
    return ""